==> owncloud-app-contacts-2%3A1.4.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/contacts/l10n/pt_PT.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Contactos",
    "Address book name" : "Nome do livro de endereços",
    "Import" : "Importar",
    "The selected image is too big (max 1MB)" : "A imagem selecionada é demasiado grande (max 1MB)",
    "No contacts in here" : "Nenhum contacto aqui",
    "Name" : "Nome",
    "Organization" : "Organização",
    "Title" : "Título ",
    "Add field ..." : "Adicionar campo ...",
    "+ New contact" : "+ Novo contacto",
    "No search result for {query}" : "Sem resultados de pesquisa para {query}",
    "_%n contact_::_%n contacts_" : ["%n contacto","%n contactos"],
    "Post office box" : "Apartado",
    "Postal code" : "Código Postal",
    "City" : "Cidade",
    "State or province" : "Distrito",
    "Country" : "País",
    "Address" : "Endereço",
    "(new group)" : "(novo grupo)",
    "Last name" : "Ultimo Nome",
    "First name" : "Primeiro Nome",
    "Additional names" : "Nomes adicionais",
    "Prefix" : "Prefixo",
    "Suffix" : "Sufixo",
    "All contacts" : "Todos os contactos",
    "Not grouped" : "Não agrupados",
    "New contact" : "Novo contacto",
    "{addressbook} shared by {owner}" : "{addressbook} partilhado por {owner}",
    "No contacts in file. Only VCard files are allowed." : "Nenhum contacto encontrado no ficheiro. Apenas são permitidos ficheiros VCard.",
    "Nickname" : "Alcunha",
    "Detailed name" : "Nome em detalhe",
    "Notes" : "Notas",
    "Website" : "Site da Internet",
    "Federated Cloud ID" : "Id. da Nuvem Federada",
    "Home" : "Início",
    "Work" : "Emprego",
    "Other" : "Outro",
    "Groups" : "Grupos",
    "Birthday" : "Aniversário",
    "Anniversary" : "Aniversário",
    "Date of death" : "Data de falecimento",
    "Email" : "Correio Eletrónico",
    "Instant messaging" : "Mensagens Instantâneas",
    "Phone" : "Telefone",
    "Mobile" : "Telemóvel",
    "Fax" : "Fax",
    "Fax home" : "Fax de casa",
    "Fax work" : "Fax do emprego",
    "Pager" : "Pager",
    "Voice" : "Voz",
    "Social network" : "Rede Social",
    "Settings" : "Definições"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-app-contacts-2%3A1.5.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/contacts/l10n/pt_PT.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Contactos",
    "Download" : "Transferir",
    "ShowURL" : "MostrarEndereço",
    "Share Addressbook" : "Partilhar Livro de contactos",
    "Share with users or groups" : "Partilhe com os utilizadores ou grupos",
    "Delete" : "Eliminar ",
    "can edit" : "pode editar",
    "Address book name" : "Nome do livro de endereços",
    "Import" : "Importar",
    "The selected image is too big (max 1MB)" : "A imagem selecionada é demasiado grande (max 1MB)",
    "No contacts in here" : "Nenhum contacto aqui",
    "Name" : "Nome",
    "Organization" : "Organização",
    "Title" : "Título ",
    "Add field ..." : "Adicionar campo ...",
    "No search result for {query}" : "Sem resultados de pesquisa para {query}",
    "_%n contact_::_%n contacts_" : ["%n contacto","%n contactos"],
    "Post office box" : "Apartado",
    "Postal code" : "Código Postal",
    "City" : "Cidade",
    "State or province" : "Distrito",
    "Country" : "País",
    "Address" : "Endereço",
    "(new group)" : "(novo grupo)",
    "Last name" : "Ultimo Nome",
    "First name" : "Primeiro Nome",
    "Additional names" : "Nomes adicionais",
    "Prefix" : "Prefixo",
    "Suffix" : "Sufixo",
    "All contacts" : "Todos os contactos",
    "Not grouped" : "Não agrupados",
    "New contact" : "Novo contacto",
    "{addressbook} shared by {owner}" : "{addressbook} partilhado por {owner}",
    "Contact could not be created." : "Não foi possível criar o contacto.",
    "No contacts in file. Only VCard files are allowed." : "Nenhum contacto encontrado no ficheiro. Apenas são permitidos ficheiros VCard.",
    "Nickname" : "Alcunha",
    "Detailed name" : "Nome em detalhe",
    "Notes" : "Notas",
    "Website" : "Site da Internet",
    "Federated Cloud ID" : "Id. da Nuvem Federada",
    "Home" : "Início",
    "Work" : "Emprego",
    "Other" : "Outro",
    "Groups" : "Grupos",
    "Birthday" : "Aniversário",
    "Anniversary" : "Aniversário",
    "Date of death" : "Data de falecimento",
    "Email" : "Correio Eletrónico",
    "Instant messaging" : "Mensagens Instantâneas",
    "Phone" : "Telefone",
    "Mobile" : "Telemóvel",
    "Fax" : "Fax",
    "Fax home" : "Fax de casa",
    "Fax work" : "Fax do emprego",
    "Pager" : "Pager",
    "Voice" : "Voz",
    "Social network" : "Rede Social",
    "Settings" : "Definições"
},
"nplurals=2; plural=(n != 1);");
